﻿using ProjectGasMachine.Entities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ProjectGasMachine.Drawnings;

/// <summary>
/// Сравнение по цвету, скорости, весу
/// </summary>

public class DrawningMachineCompareByColor : IComparer<DrawningMachine?>
{
    public int Compare(DrawningMachine? x, DrawningMachine? y)
    {
        if (x == null || x.EntityGas == null)
        {
            return 1;
        }
        if (y == null || y.EntityGas == null)
        {
            return -1;
        }
        var bodyColorCompare = y.EntityGas.BodyColor.Name.CompareTo(x.EntityGas.BodyColor.Name);
        if (bodyColorCompare != 0)
        {
            return bodyColorCompare;
        }
        if (x is DrawningGasMachine && y is DrawningGasMachine)
        {
            var additionalColorCompare = (y.EntityGas as EntityMachine).AdditionalColor.Name.CompareTo(
                (x.EntityGas as EntityMachine).AdditionalColor.Name);
            if (additionalColorCompare != 0)
            {
                return additionalColorCompare;
            }
        }
        var speedCompare = y.EntityGas.Speed.CompareTo(x.EntityGas.Speed);
        if (speedCompare != 0)
        {
            return speedCompare;
        }
        return y.EntityGas.Weight.CompareTo(x.EntityGas.Weight);

    }
}
